<div id="header">Documentation</div>

![](img/netco_logo.png)

<a name="table-of-contents" class="anchor"></a>
# Table of contents

* [Introduction](#introduction)
* [Installation and updates](install.md)
* [Accessing and navigating NETCO NMS](access.md)
* [Serial ports setup in Windows](win_port.md)
* Usage
  * [Design](design.md)
  * [Monitoring](monitoring.md)
     * [Alerts](alerts.md)
     * [Thresholds](thresholds.md)
     * [Settings](settings.md)
  * [User management](user_management.md)
* [Troubleshooting](troubleshooting.md)

<a name="introduction" class="anchor"></a>
# Introduction

SATEL NETCO NMS is an intuitive and user-friendly network configuration software for network design and management with radio network monitoring option. The software supports configuration of the Routing Setup and NMS Routing Setup modes for SATEL-EASy+ product family. NMS Routing refers to NMS (Network Management System) Message Routing feature, where messages can be automatically routed over the radio network to correct recipient terminal, monitoring and diagnostics included for the radio network. Graphical design of topology for NMS Message Routing, remote modification of settings, online storing and trending of field data with programmable alarm triggers. Routing Setup refers to Message Routing feature for SATEL-EASy+, SATELLINE-3AS NMS family radio modems, where messages can be automatically routed over the radio network to correct recipient terminal.

The user interface of the product is web-browser-based and can therefore be used both locally and remotely. Design with graphical user interface for easy optimizing network design and deployment in a few simple steps, with local and remote connection to SATEL radios. SATEL NETCO Design supports also .saxd file format, configuration files created with the SATEL NMS PC SW. Installation requires valid, company specific license key. License keys are available from [your local SATEL distributor](https://www.satel.com/where-to-buy/) or from SATEL directly.

SATEL NETCO NMS includes the following tools:

- [SATEL NETCO Design](https://www.satel.com/products/software/netco/) for network management
- [Alerta](https://alerta.io/) for alert management
- [Docker](https://www.docker.com/) for containerization
- [Grafana](https://grafana.com/) for displaying monitoring information
- [InfluxDB](https://www.influxdata.com/) for time series database

<a name="system_requirements" class="anchor"></a>
## System requirements

The system requirements are:

- Modern 4+ Core cpu.
- 8GB+ of memory.
- 1TB+ disk space.
- Ubuntu 20.04 LTS or Windows 10 or 11 with Windows Subsystem for Linux (WSL2).

Additional requirements for Windows installations:

- Requires Windows 10 64-bit Pro/Enterprise (version ~2019.09 or newer) or Windows 11.
- Requires at least one hard drive which is not Bitlocker protected
- Using other hypervisors than Microsoft Hyper-V required by WSL2 is not recommended and can lead to failure of installation or operation.
- Local Administrator rights are required
- ExecutionPolicy must allow running PowerShell scripts (see: [Enable Unrestricted Execution Policy](install.md#enable_unrestricted_execution_policy))

<a name="terminology" class="anchor"></a>
## Terminology

*Term* | *Description*
:- | :-------
**Network GUID** | An identifier which is unique to each network and will not change.
**Node GUID** | An identifier which is unique to each node and will not change.
**SatelNMS** | Satel's network protocol to communicate with modems.
**NTF** | Network Transport Format - NETCO Design's JSON file format which is used to import/export networks across systems.
**MSPE** | Monitoring Specification - The definition of thresholds to apply warning / alarm criteria to received values.
**Alert** | Alerts are announcing abnormal situations and conditions requiring attention. Alerts are divided in two types: alarms and warnings.
**Alarm** | An alert with is the highest priority: a condition requiring immediate attention
**Warning** | An alert condition requiring no immediate attention. Warnings are presented for precautionary reasons to highlight changed conditions before they become critical.
**Severity** | Which alert condition was met: either Critical or Warning.
**Status** | Current alert status: one of Open/Closed/Shelved/Acknowledged. See [Alert status](alerts.md#alert_status) for more information.
**Resource** | This tells which network and node generated the alert.
**Event** | This specifies alarm type. For example: 'threshold' or 'deadband'.
**Threshold** | The limits that received values are compared against to create alerts. These are set in the [Node monitoring settings in Design](design.md#node_monitoring_settings).
**Deadband** | Node is not responding. Deadband Timeout can be configured in the [Network monitoring settings in Design](design.md#network_monitoring_settings).

<a name="known_issues" class="anchor"></a>
## Known issues
* Network monitoring dashboard: Link RSSI and SNR are only identified by RMAC id:s, human readable version is pending.
* Network monitoring dashboard: Live Monitoring Map View does not currently display alert status, is always green
* Network monitoring dashboard: Live Monitoring Map View may display the error "Failed to get network NTFi by GUID=undefined Failed to get latest NTFi."
  * This happens if the dashboard is accessed via Grafana's dashboard list next to the main menu. The issue does not occur when the dashboard is accessed from the Home dashboard's network list.
* Settings: If SMTP settings are not correct, diagnosing the issue may be difficult as the UI does not display SMTP error messages.
* User management displays an empty page if not logged in
* Design & Monitoring: RSSI alarm/warning threshold can not currently be defined in Design.
* Design & Monitoring: SatelNMS protocol's Anycast mode is out of scope for this release
* Design & Monitoring: SNMP monitoring is out of scope for this release
* Design & Monitoring: Non-responding nodes are polled with regular interval until user disables monitoring on that node
