<div id="header"><a href="/doc">Documentation</a> / Installation and updates</div>

# Installing

NETCO NMS installation packages are distributed in .zip file format.

## 1. Copy the package to the target machine

Ensure the target machine adheres to the [system requirements](index.md#system_requirements)

## 2. Extract archive and open terminal in created folder

Open the target folder with NETCO NMS package in the file manager: ![File manager icon](img/installation_file_manager_icon.png)

Right click on the zip file and select ***Extract here***.

Next, right click on the created folder and select ***Open in Terminal***.

![Extracting zip file](img/installation_extract.png)![Extracting zip file](img/installation_open_terminal.png)

## 3a. Launch installer in the terminal

Issue the following commands:

> chmod +x ./environments/compose-for-single-node-linux.sh<br>
> sudo ./environments/compose-for-single-node-linux.sh<br>
> sudo ./LocalUp.ps1

## 3b. Installation instructions for Windows 10

1. Download Docker Desktop for Windows

[https://www.docker.com/products/docker-desktop](https://www.docker.com/products/docker-desktop)

2. Install Docker Desktop for Windows.

If it is requested, please create docker.com user account.

Accept default suggestions:

[x] Install required Windows components for WSL2

[x] add shortcut to Desktop


3. Enable Unrestricted Execution Policy

To enable running Powershell scripts, start Powershell with "Run as Administrator" and run the following:

`Set-Executionpolicy Unrestricted`

This will prompt:

> Execution Policy Change
> The execution policy helps protect you from scripts that you do not trust. Changing the execution policy might expose
> you to the security risks described in the about_Execution_Policies help topic at
> https:/go.microsoft.com/fwlink/?LinkID=135170. Do you want to change the execution policy?
> [Y] Yes  [A] Yes to All  [N] No  [L] No to All  [S] Suspend  [?] Help (default is "N"):

Type **a** and press Enter.

4. Start the NETCO NMS stack

Now go to the directory where you extracted the zip with the Administrator terminal, and run this:

`.\LocalUp.ps1`

(!) If you are asked to trust .ps1 scripts in this
   directory during the following steps, please choose
   option R = Run once. You may have to do this 2-3 times
   during installation.

You will be presented a menu where you can change configuration. See more information about the menu in next chapter.

The installation takes some minutes and after that you are presented with an url to direct your browser to and admin username and password. Please save the password for later logins as it is the only way to login as admin.

## 4. Initial configuration

At first LocalUp.ps1 will allow making changes to the initial configuration. The available options are:

**Option** |**OS**| **Description**
|:--   | :--- |:--
|1. Allow access to local serial device: none |Linux| For installations where a local serial port on the NETCO NMS machine is used to access the radio network's root node. Common examples may be ***/dev/ttyS0*** or ***/dev/ttyUSB0***. The ttyS* devices are typically hardware serial ports directly on the computer's motherboard. For USB serial adapters the device name can be obtained by looking at `dmesg |tail` output immediately after the adapter has been connected.
|2. Listen address for NETCO NMS user interface: 0.0.0.0 | Win Linux|The default listens to all network interfaces. If NETCO NMS should be restricted to a specific network interface, provide its IP address here.
|3. Listen port for NETCO NMS user interface: 80 | Win Linux | Listen port
|4. Retention policy for monitoring data: INF |Win Linux| The time to store monitoring data in the database. The value must be either a number and unit [e.g. '105d'] or 'INF', which will never delete monitoring data. **Note: This can not be changed later.**
|5. Internal Docker address space: 10.99.99.0/24 |Win Linux| NETCO NMS creates a subnet to communicate across its components locally. This address space is not otherwise visible to NETCO NMS users, however it should not collide with networks within the Intranet.
|6. User profile path | Win | NETCO NMS istaller will configure WSL2 to limit memory usage with 4Gb. A file ".wslconfig" will be saved to the user profile folder.

Note: If you are installing NETCO NMS on a Windows machine and wish to establish a serial connection to your devices, it is recommended to utilize port mapping scripts, which can be found in ./win_ports folder. These scripts assist in mapping TCP ports within the Docker container to the serial port on your Windows host machine. More information is in a chapter [Serial ports setup in Windows](win_port.md)


When ***Configure option:*** is prompted, most users can simply press Enter to continue with default settings.

![NETCO NMS LocalUp.ps1 start example](img/installation_localup_example1.png)

<a name="installation_complete" class="anchor"></a>
## 5. Installation complete

Once installation is completed, the terminal will return to a command prompt. NETCO NMS is now installed and running. It will also be started automatically on reboot.

![NETCO NMS LocalUp.ps1 completed example](img/installation_localup_example2.png)

Follow the instructions in green to log in to NETCO NMS. The displayed password is randomly generated and is unique to each system. **Make sure to store or [change the password](user_management.md) for later use.**

# Updating

Simply extract a newer NETCO NMS package to some folder and run LocalUp.ps1.

**Note**: A new initial admin password will be generated. If you wish to use your previous admin password, please ensure to copy the .env.secret file from the directory where your previous version of NETCO NMS was extracted before running LocalUp.ps1.


# Uninstalling

Uninstallation involves the following three step process:

* Shut down the NETCO NMS stack:
 * on Ubuntu: open a terminal, enter the extracted NETCO NMS folder and run `sudo ./LocalDown.ps1`
 * on Windows: open a terminal by right clicking and selecting "Run as Administrator". Enter the extracted NETCO NMS folder and run `.\LocalDown.ps1`
* Remove unused docker images: `docker image prune -a`
* Remove unused docker volumes: `docker volume prune` -- this deletes NETCO NMS data including imported networks and monitoring data

These instructions assume docker was set up specifically for NETCO NMS. If additional dockers are installed, make sure to prune NETCO NMS specific containers and volumes only.

